@@ -1,6 +1,6 @@
 package TPath::AttributeTest;
 {
-  $TPath::AttributeTest::VERSION = '0.016';
+  $TPath::AttributeTest::VERSION = '0.017';
 }
 
 # ABSTRACT: compares an attribute value to another value
@@ -72,29 +72,33 @@ sub _i_func {
         my $s_func = _s_func( $self->left );
         for ($i_type) {
             when (0) {
+                my $l = length $v;
                 return sub {
                     my ( $self, $ctx ) = @_;
                     my $lv = $self->$s_func($ctx);
-                    my $index = index $lv, $v;
-                    return $index == 0 ? 1 : undef;
+                    return undef unless length $lv >= $l;
+                    $lv = substr $lv, 0, $l;
+                    return $lv eq $v ? 1 : undef;
                 };
             }
             when (1) {
                 return sub {
                     my ( $self, $ctx ) = @_;
                     my $lv = $self->$s_func($ctx);
+                    return undef unless defined $lv;
                     my $index = index $lv, $v;
                     return $index > -1 ? 1 : undef;
                 };
             }
             when (2) {
-                my $lr = length $v;
+                my $l = length $v;
                 return sub {
                     my ( $self, $ctx ) = @_;
                     my $lv = $self->$s_func($ctx);
-                    my $index = index $lv, $v;
-                    return $index > -1
-                      && $index == length($lv) - $lr ? 1 : undef;
+                    return undef unless defined $lv;
+                    return undef unless length $lv >= $l;
+                    $lv = substr $lv, -$l;
+                    return $lv eq $v ? 1 : undef;
                 };
             }
         }
@@ -992,7 +996,7 @@ TPath::AttributeTest - compares an attribute value to another value
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 DESCRIPTION
 
